The gadgets package
===================

.. automodule:: parceqt.gadgets


The gadgets.extraselectionmanager module
----------------------------------------

.. automodule:: parceqt.gadgets.extraselectionmanager
    :members:
    :undoc-members:
    :show-inheritance:


The gadgets.languagemenuaction module
----------------------------------------

.. automodule:: parceqt.gadgets.languagemenuaction
    :members:
    :undoc-members:
    :show-inheritance:

